@@ -3,8 +3,8 @@ kcvcheck <-
 {
     if (!is.factor(y)) {y <- factor(y)}
     if (length(unique(y)) == 1L) {
-      stop("Input 'y' must contain some variation (i.e., cannot contain \n
-           only a single type of label).")
+      stop("Input 'y' must contain some variation (i.e., cannot contain only \n
+           a single type of label).")
     }
     if (is.null(nfolds)) {
       nfolds <- 10
@@ -16,14 +16,14 @@ kcvcheck <-
         stop("Input 'nfolds' must contain only a single value.")
       }
       if ((nfolds %% 1) != 0) {stop("Input 'nfolds' must be an integer.")}
-      if ((nfolds < 2) | (nfolds > length(y))) {
+      if ((nfolds < 2) || (nfolds > length(y))) {
         stop("Input 'nfolds' must be an integer between 2 and the \n
              number of observations, inclusive. Alternatively, the \n
              number of observations cannot be less than 'nfolds'.")
       }
     }
     if (is.null(parallel)) {
-      parallel <- FALSE
+      parallel <- F
     } else {
       if (!(is.logical(parallel))) {
         stop("Input 'parallel' must be of class 'logical'.")
